==> crm-static-1.3.0.0.release.jar: com/biz/crm/eunm/dms/SaleGoalEunm.java <==
package com.biz.crm.eunm.dms;

/**
 * @Description:
 * @Author: zhangyuzhu
 * @Date: 2020/9/15 16:23
 **/
public class SaleGoalEunm {

  /**
   * 根据编码获取枚举
   * @param code
   * @return
   */
  public static ObjectType getObjectTypeByCode(Integer code) {
    ObjectType[] types = ObjectType.values();
    for (ObjectType type : types) {
      if (type.getCode().equals(code)) {
        return type;
      }
    }
    return null;
  }

  /**
   * 根据编码获取任务类型枚举
   * @param code
   * @return
   */
  public static TaskType getTaskTypeByCode(Integer code) {
    TaskType[] types = TaskType.values();
    for(TaskType type : types) {
      if(type.getCode().equals(code)) {
        return type;
      }
    }
    return null;
  }

  /**
   * 销量目标类型
   */
  public enum goalType {
    ROUTINE(0, "常规"),
    GOODS(1, "单品"),
    PRODUCTLQVEL(2, "系列");

    private Integer code;
    private String value;

    goalType() {
    }

    goalType(Integer code, String value) {
      this.code = code;
      this.value = value;
    }

    public Integer getCode() {
      return code;
    }

    public String getValue() {
      return value;
    }
  }

  /**
   * 对象维度枚举
   */
  public enum ObjectType {
    CUSTOMER(1, "客户维度"),
    ORGANIZATION(2, "组织维度"),
    TERMINAL(3, "终端维度"),
    ;

    private Integer code;
    private String value;

    ObjectType(Integer code, String value) {
      this.code = code;
      this.value = value;
    }

    public Integer getCode() {
      return code;
    }

    public String getValue() {
      return value;
    }
  }

  /**
   * 任务类型枚举
   */
  public enum TaskType {
    YEARLY(1, "年度"),
    QUARTER(2, "季度"),
    MONTHLY(3, "月度"),
    ;

    private Integer code;
    private String value;

    TaskType(Integer code, String value) {
      this.code = code;
      this.value = value;
    }

    public Integer getCode() {
      return code;
    }

    public String getValue() {
      return value;
    }
  }
}

==> crm-static-1.3.0.6.77.release.jar: com/biz/crm/eunm/dms/SaleGoalEunm.java <==
package com.biz.crm.eunm.dms;

/**
 * @Description:
 * @Author: zhangyuzhu
 * @Date: 2020/9/15 16:23
 **/
public class SaleGoalEunm {

  /**
   * 根据编码获取枚举
   * @param code
   * @return
   */
  public static ObjectType getObjectTypeByCode(Integer code) {
    ObjectType[] types = ObjectType.values();
    for (ObjectType type : types) {
      if (type.getCode().equals(code)) {
        return type;
      }
    }
    return null;
  }

  /**
   * 根据编码获取任务类型枚举
   * @param code
   * @return
   */
  public static TaskType getTaskTypeByCode(Integer code) {
    TaskType[] types = TaskType.values();
    for(TaskType type : types) {
      if(type.getCode().equals(code)) {
        return type;
      }
    }
    return null;
  }

  /**
   * 销量目标类型
   */
  public enum GoalType {
    ROUTINE(0, "常规"),
    GOODS(1, "单品"),
    PRODUCT_LEVEL(2, "系列");

    private Integer code;
    private String value;

    GoalType() {
    }

    GoalType(Integer code, String value) {
      this.code = code;
      this.value = value;
    }

    public Integer getCode() {
      return code;
    }

    public String getValue() {
      return value;
    }
  }

  /**
   * 对象维度枚举
   */
  public enum ObjectType {
    CUSTOMER(1, "客户维度"),
    ORGANIZATION(2, "组织维度"),
    TERMINAL(3, "终端维度"),
    ;

    private Integer code;
    private String value;

    ObjectType(Integer code, String value) {
      this.code = code;
      this.value = value;
    }

    public Integer getCode() {
      return code;
    }

    public String getValue() {
      return value;
    }
  }

  /**
   * 任务类型枚举
   */
  public enum TaskType {
    YEARLY(1, "年度"),
    QUARTER(2, "季度"),
    MONTHLY(3, "月度"),
    ;

    private Integer code;
    private String value;

    TaskType(Integer code, String value) {
      this.code = code;
      this.value = value;
    }

    public Integer getCode() {
      return code;
    }

    public String getValue() {
      return value;
    }
  }
}
